<!--- 
	csw-icontextblock-counter.cfc 

	Counter Up 2.1 Plugin:
	- https://github.com/ciromattia/jquery.counterup
	Waypoints Plugin:
	- http://imakewebthings.com/waypoints
	
	Version: [2018-01-18 1:15]
--->

<cfcomponent displayname="csw-icontextblock-counter" output="false" hint="Common Icon Textblock Counter Functions" extends="_cs_widgets.csw-icontextblock.renderhandlers.csw-icontextblock">

	<cffunction name="loadResources" access="public" output="Yes" returntype="void">
		
		<cfscript>
			// load resources from base icon textblock
			super.loadResources();
		
			Server.CommonSpot.udf.resources.loadResources("cswIconTextblockCounter");
			Server.CommonSpot.udf.resources.loadResources("Waypoints");  // Waypoints is a library that makes it easy to execute a function whenever you scroll to an element.
			Server.CommonSpot.udf.resources.loadResources("CounterUp");
	
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswIconTextblockCounter_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswIconTextblockCounter_custom");
		</cfscript>
		
	</cffunction>
	
	

	<cffunction name="loadProperties" access="public" returntype="struct" output="Yes">
		<cfargument name="elementInfo" type="struct" required="Yes">
		<cfargument name="rhCaller" type="struct" required="false" default="#StructNew()#">
		<cfargument name="showDataError" type="boolean" required="false" default="true">
		
		<cfscript>
			var widgetMetadataFormName = "CSW IconTextblock";	
			var props = StructNew();
			var rhMetadata = arguments.ElementInfo.RenderHandlerMetaData;
			var widgetData = StructNew();
			
			// load properties from base icon textblock
			props = super.loadProperties(arguments.elementInfo,arguments.rhCaller,false);
		
			
			// Metadata Form for the  Icon Counter Textblock Widget. 
			widgetMetadataFormName = "CSW IconTextblock Counter";	
			
			// Check for Props and Layout Binding
			if( NOT hasPropsLayoutBinding(ElementInfo=arguments.elementInfo,metadataFormName=widgetMetadataFormName,rhCaller=arguments.rhCaller) )
				return props;			
			
			// 
			// Get Metadata (Icon Counter Textblock metadata)
			// ----------------------------------------------
			widgetData = rhMetadata[widgetMetadataFormName];
			
			
			/**********************************/
			/**** COUNTER PROPERTIES TAB ******/
			/**********************************/
			
			// Counter (STRUCT)
			props.counter = getFieldSettings(widgetData=widgetData, field='Counter', defColor='black');		
			
			// Counter Refresh
			props.counterRefresh = getStandardField( widgetData=widgetData, field='Counter_Refresh', defValue='1000' );			
			
			// Counter Duration
			props.counterDuration = getStandardField( widgetData=widgetData, field='Counter_Duration', defValue='6000' );			
		
			return props;
		</cfscript>
	</cffunction>
	
	
	<cffunction name="getItemData" access="public" output="Yes" returntype="struct">
		<cfargument name="valuesStruct" type="struct" required="Yes">
		
		<cfscript>
			var data = super.getItemData(arguments.valuesStruct);
			var values = arguments.valuesStruct;
			
			// Counter
			data.counter = '';
			if( structKeyExists(values,'counter') )
				data.counter = values.counter;	
			
			return data;
		</cfscript>
		
	</cffunction>
	
	
	
	<cffunction name="renderOther" access="public" returntype="void" output="Yes">
		<cfargument name="dataStruct" type="struct" required="yes">
		<cfargument name="propsStruct" type="struct" required="yes">
		
		<cfscript>
			var data = arguments.dataStruct;
			var props = arguments.propsStruct;
			
			var StyleAttr = '';
			var classes = '';
			var tag = 'div';
			
			if( len(props.counter.tag) )
				tag = props.counter.tag;

			if( len(props.counter.color) )
				styleAttr = styleAttr & ' color:#props.counter.color#;';
			if( len(props.counter.padding) )
				styleAttr = styleAttr & ' padding:#props.counter.padding#;';				
			if( len(styleAttr) )
				styleAttr = 'style="#styleAttr#"';
				
			if( len(props.counter.size) )
				classes = trim(classes & ' #props.counter.size#');
			if( len(props.counter.align) )
				classes = trim(classes & ' #props.counter.align#');				
			if( len(props.counter.fontClasses) )
				classes = trim(classes & ' #props.counter.fontClasses#');			
		</cfscript>
		
		<cfoutput>
			<cfif len(data.counter)>
				<#tag# class="cswCounter #classes# cswCounter_#request.element.id#" #styleAttr#>#data.counter#</#tag#>
			</cfif>
		</cfoutput>
		
	</cffunction>


	<cffunction name="getAndRenderItems" access="public" output="Yes" returntype="void">
		<cfargument name="elementDataStruct" type="struct" required="Yes">
		<cfargument name="propsStruct" type="struct" required="Yes">
		
		<cfscript>
			var elementData = arguments.elementDataStruct;
			var props = arguments.propsStruct;
			var items = ArrayNew(1);
			var totalItems = 0;
			var cswIconTextblockCounterJS = '';
			
			// Get Records from the Element as an Array of Structures
			if( StructKeyExists(elementData, 'PropertyValues') AND ArrayLen(elementData.PropertyValues) )
				items = elementData.PropertyValues;
	
			totalItems = ArrayLen(items);
			
			// Call the getAndRenderItems from icontextblock
			super.getAndRenderItems(elementDataStruct=elementData,propsStruct=props);
			
			// Call the renderCounterJS for counter
			if ( totalItems ) 
				renderCounterJS(propsStruct=props);
		</cfscript>
	</cffunction>	
	
	
	<cffunction name="renderCounterJS" access="public" output="Yes" returntype="void">
		<cfargument name="propsStruct" type="struct" required="Yes">
		
		<cfscript>
			var props = arguments.propsStruct;
			var cswIconTextblockCounterJS = '';
		</cfscript>
		
		<!---
			Load Javascript required for counter
		--->
		<cfsavecontent variable="cswIconTextblockCounterJS">
		<cfoutput>
			jQuery(document).ready(function() {
				initIconCounter('cswCounter_#request.element.id#', #props.counterRefresh#, #props.counterDuration#);
				//initIconCounterInstance('cswCounter_#request.element.id#', #props.counterRefresh#, #props.counterDuration#);
			});
		</cfoutput>
		</cfsavecontent>

		<cfscript>
			// Load custom javascript at the bottom of the page.
			Server.CommonSpot.udf.resources.addFooterJS(cswIconTextblockCounterJS, 'TERTIARY');
		</cfscript>
	</cffunction>
	
</cfcomponent>